@@ -158,8 +158,10 @@ def process_data_to_same_gene(gene, root_dir, output_dir, mode):
         dataset = dataset_list[l]
         if '.txt' in dataset or '.csv' in dataset:
             all_data = pd.read_csv(root_dir + dataset, sep='\t')
-        if '.h5' in dataset and '_processed' not in dataset:
+        elif '.h5' in dataset and '_processed' not in dataset:
             all_data = pd.read_hdf(root_dir + dataset)
+        else:
+            continue
         add_gene = []
         for gene_ in gene:
             if gene_ not in all_data.columns:
